==> sil-machine-0.5.0.tar.gz: sil-machine-0.5.0/machine/corpora/__init__.py <==
from .aligned_word_pair import AlignedWordPair
from .alignment_collection import AlignmentCollection
from .alignment_corpus import AlignmentCorpus
from .alignment_row import AlignmentRow
from .corpus import Corpus
from .dbl_bundle_text import DblBundleText
from .dbl_bundle_text_corpus import DblBundleTextCorpus
from .dictionary_alignment_corpus import DictionaryAlignmentCorpus
from .dictionary_text_corpus import DictionaryTextCorpus
from .flatten import flatten
from .memory_alignment_collection import MemoryAlignmentCollection
from .memory_text import MemoryText
from .parallel_text_corpus import ParallelTextCorpus
from .parallel_text_row import ParallelTextRow
from .paratext_text_corpus import ParatextTextCorpus
from .row_ref import RowRef
from .scripture_text_corpus import ScriptureTextCorpus
from .standard_parallel_text_corpus import StandardParallelTextCorpus
from .text import Text
from .text_corpus import TextCorpus
from .text_file_alignment_collection import TextFileAlignmentCollection
from .text_file_alignment_corpus import TextFileAlignmentCorpus
from .text_file_text import TextFileText
from .text_file_text_corpus import TextFileTextCorpus
from .text_row import TextRow
from .token_processors import (
    escape_spaces,
    lowercase,
    nfc_normalize,
    nfd_normalize,
    nfkc_normalize,
    nfkd_normalize,
    normalize,
    unescape_spaces,
)
from .usfm_file_text import UsfmFileText
from .usfm_file_text_corpus import UsfmFileTextCorpus
from .usfm_marker import (
    UsfmJustification,
    UsfmMarker,
    UsfmStyleAttribute,
    UsfmStyleType,
    UsfmTextProperties,
    UsfmTextType,
)
from .usfm_stylesheet import UsfmStylesheet
from .usx_file_alignment_collection import UsxFileAlignmentCollection
from .usx_file_alignment_corpus import UsxFileAlignmentCorpus
from .usx_file_text import UsxFileText
from .usx_file_text_corpus import UsxFileTextCorpus

__all__ = [
    "AlignedWordPair",
    "AlignmentCollection",
    "AlignmentCorpus",
    "AlignmentRow",
    "Corpus",
    "DblBundleText",
    "DblBundleTextCorpus",
    "DictionaryAlignmentCorpus",
    "DictionaryTextCorpus",
    "MemoryAlignmentCollection",
    "MemoryText",
    "ParallelTextCorpus",
    "ParallelTextRow",
    "ParatextTextCorpus",
    "RowRef",
    "ScriptureTextCorpus",
    "StandardParallelTextCorpus",
    "Text",
    "TextCorpus",
    "TextFileAlignmentCollection",
    "TextFileAlignmentCorpus",
    "TextFileText",
    "TextFileTextCorpus",
    "TextRow",
    "UsfmFileText",
    "UsfmFileTextCorpus",
    "UsfmJustification",
    "UsfmMarker",
    "UsfmStyleAttribute",
    "UsfmStyleType",
    "UsfmStylesheet",
    "UsfmTextProperties",
    "UsfmTextType",
    "UsxFileAlignmentCollection",
    "UsxFileAlignmentCorpus",
    "UsxFileText",
    "UsxFileTextCorpus",
    "escape_spaces",
    "flatten",
    "lowercase",
    "nfc_normalize",
    "nfd_normalize",
    "nfkc_normalize",
    "nfkd_normalize",
    "normalize",
    "unescape_spaces",
]

==> sil-machine-0.7.1.tar.gz: sil-machine-0.7.1/machine/corpora/__init__.py <==
from .aligned_word_pair import AlignedWordPair
from .alignment_collection import AlignmentCollection
from .alignment_corpus import AlignmentCorpus
from .alignment_row import AlignmentRow
from .corpora_utils import batch
from .corpus import Corpus
from .dbl_bundle_text_corpus import DblBundleTextCorpus
from .dictionary_alignment_corpus import DictionaryAlignmentCorpus
from .dictionary_text_corpus import DictionaryTextCorpus
from .flatten import flatten
from .memory_alignment_collection import MemoryAlignmentCollection
from .memory_text import MemoryText
from .parallel_text_corpus import ParallelTextCorpus, flatten_parallel_text_corpora
from .parallel_text_row import ParallelTextRow
from .paratext_backup_text_corpus import ParatextBackupTextCorpus
from .paratext_text_corpus import ParatextTextCorpus
from .scripture_text_corpus import ScriptureTextCorpus
from .standard_parallel_text_corpus import StandardParallelTextCorpus
from .text import Text
from .text_corpus import TextCorpus, flatten_text_corpora
from .text_file_alignment_collection import TextFileAlignmentCollection
from .text_file_alignment_corpus import TextFileAlignmentCorpus
from .text_file_ref import TextFileRef
from .text_file_text import TextFileText
from .text_file_text_corpus import TextFileTextCorpus
from .text_row import TextRow
from .token_processors import (
    escape_spaces,
    lowercase,
    nfc_normalize,
    nfd_normalize,
    nfkc_normalize,
    nfkd_normalize,
    normalize,
    unescape_spaces,
)
from .usfm_file_text import UsfmFileText
from .usfm_file_text_corpus import UsfmFileTextCorpus
from .usfm_parser import UsfmParser, parse_usfm
from .usfm_parser_handler import UsfmParserHandler
from .usfm_parser_state import UsfmElementType, UsfmParserElement, UsfmParserState
from .usfm_stylesheet import UsfmStylesheet
from .usfm_tag import UsfmJustification, UsfmStyleAttribute, UsfmStyleType, UsfmTag, UsfmTextProperties, UsfmTextType
from .usfm_token import UsfmAttribute, UsfmToken, UsfmTokenType
from .usfm_tokenizer import UsfmTokenizer
from .usx_file_alignment_collection import UsxFileAlignmentCollection
from .usx_file_alignment_corpus import UsxFileAlignmentCorpus
from .usx_file_text import UsxFileText
from .usx_file_text_corpus import UsxFileTextCorpus
from .usx_zip_text import UsxZipText

__all__ = [
    "AlignedWordPair",
    "AlignmentCollection",
    "AlignmentCorpus",
    "AlignmentRow",
    "Corpus",
    "DblBundleTextCorpus",
    "DictionaryAlignmentCorpus",
    "DictionaryTextCorpus",
    "MemoryAlignmentCollection",
    "MemoryText",
    "ParallelTextCorpus",
    "ParallelTextRow",
    "ParatextBackupTextCorpus",
    "ParatextTextCorpus",
    "ScriptureTextCorpus",
    "StandardParallelTextCorpus",
    "Text",
    "TextCorpus",
    "TextFileAlignmentCollection",
    "TextFileAlignmentCorpus",
    "TextFileRef",
    "TextFileText",
    "TextFileTextCorpus",
    "TextRow",
    "UsfmAttribute",
    "UsfmElementType",
    "UsfmFileText",
    "UsfmFileTextCorpus",
    "UsfmJustification",
    "UsfmParser",
    "UsfmParserElement",
    "UsfmParserHandler",
    "UsfmParserState",
    "UsfmStyleAttribute",
    "UsfmStyleType",
    "UsfmStylesheet",
    "UsfmTag",
    "UsfmTextProperties",
    "UsfmTextType",
    "UsfmToken",
    "UsfmTokenType",
    "UsfmTokenizer",
    "UsxFileAlignmentCollection",
    "UsxFileAlignmentCorpus",
    "UsxFileText",
    "UsxFileTextCorpus",
    "UsxZipText",
    "batch",
    "escape_spaces",
    "flatten",
    "flatten_parallel_text_corpora",
    "flatten_text_corpora",
    "lowercase",
    "nfc_normalize",
    "nfd_normalize",
    "nfkc_normalize",
    "nfkd_normalize",
    "normalize",
    "parse_usfm",
    "unescape_spaces",
]
